@@ -13,7 +13,6 @@ class FenceDaemon(TagObject):
     self.TAG_NAME = TAG_NAME 
     self.addAttribute("post_join_delay",POST_JOIN_DEFAULT)
     self.addAttribute("post_fail_delay",POST_FAIL_DEFAULT)
-    self.addAttribute("clean_start",CLEAN_START_DEFAULT)
 
   def getPostJoinDelay(self):
     val = self.getAttribute("post_join_delay")
@@ -23,8 +22,4 @@ class FenceDaemon(TagObject):
     val = self.getAttribute("post_fail_delay")
     return val
 
-  def getCleanStart(self):
-    val = self.getAttribute("clean_start")
-    return val
-
 
