@@ -19,17 +19,27 @@ from Cman import Cman
 from Gulm import Gulm
 from Lockserver import Lockserver
 from Ip import Ip
+from LVM import LVM
+from Apache import Apache
+from Postgres8 import Postgres8
+from MySQL import MySQL
+from Tomcat5 import Tomcat5
+from OpenLDAP import OpenLDAP
 from Script import Script
 from NFSClient import NFSClient
 from NFSExport import NFSExport
 from Fs import Fs
 from Samba import Samba
+from SybaseASE import SybaseASE
 from Multicast import Multicast
 from FenceDaemon import FenceDaemon
+from FenceXVMd import FenceXVMd
 from Netfs import Netfs
 from Clusterfs import Clusterfs
 from Resources import Resources
 from Service import Service
+from SAPDatabase import SAPDatabase
+from SAPInstance import SAPInstance
 from QuorumD import QuorumD
 from Heuristic import Heuristic
 from Vm import Vm
@@ -55,14 +65,24 @@ TAGNAMES={ 'cluster':Cluster,
            'lockserver':Lockserver,
            'rm':Rm,
            'service':Service,
+           'SAPDatabase':SAPDatabase,
+           'SAPInstance':SAPInstance,
            'resources':Resources,
            'failoverdomain':FailoverDomain,
            'failoverdomains':FailoverDomains,
            'failoverdomainnode':FailoverDomainNode,
            'ip':Ip,
+           'lvm':LVM,
+           'postgres-8':Postgres8,
+           'tomcat-5':Tomcat5,
+           'openldap':OpenLDAP,
+           'apache':Apache,
+           'mysql':MySQL,
            'fs':Fs,
            'smb':Samba,
+           'ASEHAagent':SybaseASE,
            'fence_daemon':FenceDaemon,
+           'fence_xvmd':FenceXVMd,
            'multicast':Multicast,
            'clusterfs':Clusterfs,
            'netfs':Netfs,
@@ -83,6 +103,7 @@ FENCEDEVICES_PTR_STR="fencedevices"
 RESOURCEMANAGER_PTR_STR="rm"
 RESOURCES_PTR_STR="resources"
 FENCEDAEMON_PTR_STR="fence_daemon"
+FENCEXVMD_PTR_STR="fence_xvmd"
 SERVICE="service"
 GULM_TAG_STR="gulm"
 MCAST_STR="multicast"
@@ -116,6 +137,7 @@ class ModelBuilder:
     self.resourcemanager_ptr = None
     self.resources_ptr = None
     self.fence_daemon_ptr = None
+    self.fence_xvmd_ptr = None
     self.quorumd_ptr = new_quorumdisk
     self.unusual_items = list()
     self.command_handler = CommandHandler()
@@ -205,6 +227,8 @@ class ModelBuilder:
         self.CMAN_ptr = new_object
       elif parent_node.nodeName == MCAST_STR:
         self.usesMulticast = True
+      elif parent_node.nodeName == FENCEXVMD_PTR_STR:
+        self.fence_xvmd_ptr = new_object
 
     else:
       return None
@@ -539,6 +563,9 @@ class ModelBuilder:
   def getFenceDevicePtr(self):
     return self.fencedevices_ptr
 
+  def getFenceXVMdPtr(self):
+    return self.fence_xvmd_ptr
+
   def getFailoverDomains(self):
     if self.failoverdomains_ptr == None:
       return list()
@@ -953,6 +980,8 @@ class ModelBuilder:
         kids = level.getChildren()
         l = list()
         for kid in kids:
+          if kid.hasNativeOptionSet() == True:
+            continue
           if kid.isPowerController() == True:
             l.append(kid)
         if len(l) > 1:  #Means we found multiple PCs in the same level
@@ -979,6 +1008,13 @@ class ModelBuilder:
         for level in levels:
           kids = level.getChildren()
           for kid in kids: #kids are actual fence instance objects
+            #Need to pass over this device if:
+            ##1) It is not a power controller, or
+            ##2) It had an initial option attr when the model was constructed
+            if not kid.isPowerController():
+              continue
+            if kid.hasNativeOptionSet():
+              continue
             res = kid.getAttribute("option")
             if res != None:
               if res == "off":
