@@ -7,6 +7,7 @@ _ = gettext.gettext
 
 RESOURCE_TYPE=_("NFS Client: ")
 TAG_NAME = "nfsclient"
+DENY_ALL_CHILDREN = True
 
 class NFSClient(BaseResource):
   def __init__(self):
@@ -14,3 +15,4 @@ class NFSClient(BaseResource):
     self.TAG_NAME = TAG_NAME
     self.resource_type = RESOURCE_TYPE
     self.addAttribute("name"," ")
+    self.deny_all_children = DENY_ALL_CHILDREN
