@@ -148,6 +148,14 @@ class ResourceHandler:
 
   def pop_ip(self, attrs):
     addr = attrs["address"]
+    #look for subnet suffix
+    subnet = ""
+    dex = addr.find("/")
+    if dex != 0:
+      just_addr = addr[:dex]
+      subnet = addr[dex+1:]
+      addr = just_addr
+    self.subnet.set_text(subnet) 
     self.ip.setAddrFromString(addr)
     monitor = attrs["monitor_link"]
     if (monitor == None) or (monitor == False) or (monitor == "no") or (monitor == "0"):
@@ -516,6 +524,24 @@ class ResourceHandler:
     except KeyError, e:
       self.sapdb_abap_cbox.set_active(False)
 
+    try:
+      ar = attrs["AUTOMATIC_RECOVER"]
+      if ar == "TRUE" or ar == "1" or ar == "True":
+        self.sapdb_autostart.set_active(True)
+      else:
+        self.sapdb_autostart.set_active(False)
+    except KeyError, e:
+      self.sapdb_autostart.set_active(False)
+
+    try:
+      am = attrs["STRICT_MONITORING"]
+      if am == "TRUE" or am == "1" or am == "True":
+        self.sapdb_appmonitor.set_active(True)
+      else:
+        self.sapdb_appmonitor.set_active(False)
+    except KeyError, e:
+      self.sapdb_appmonitor.set_active(False)
+
     try:
       self.sapdb_bootstrap.set_text(attrs["DIR_BOOTSTRAP"])
     except KeyError, e:
@@ -531,6 +557,36 @@ class ResourceHandler:
     except KeyError, e:
       self.sapdb_tns.set_text("")
 
+    try:
+      self.sapdb_sdkpath.set_text(attrs["JAVA_HOME"])
+    except KeyError, e:
+      self.sapdb_sdkpath.set_text("")
+
+    try:
+      self.sapdb_jdbc.set_text(attrs["DB_JARS"])
+    except KeyError, e:
+      self.sapdb_jdbc.set_text("")
+
+    try:
+      self.sapdb_prestart.set_text(attrs["PRE_START_USEREXIT"])
+    except KeyError, e:
+      self.sapdb_prestart.set_text("")
+
+    try:
+      self.sapdb_poststart.set_text(attrs["POST_START_USEREXIT"])
+    except KeyError, e:
+      self.sapdb_poststart.set_text("")
+
+    try:
+      self.sapdb_prestop.set_text(attrs["PRE_STOP_USEREXIT"])
+    except KeyError, e:
+      self.sapdb_prestop.set_text("")
+
+    try:
+      self.sapdb_poststop.set_text(attrs["POST_STOP_USEREXIT"])
+    except KeyError, e:
+      self.sapdb_poststop.set_text("")
+
   def pop_sap(self, attrs):
     try:
       self.sap_name.set_text(attrs["InstanceName"])
@@ -542,6 +598,15 @@ class ResourceHandler:
     except KeyError, e:
       self.sap_execdir.set_text("")
 
+    try:
+      ar = attrs["AUTOMATIC_RECOVER"]
+      if ar == "TRUE" or ar == "1" or ar == "True":
+        self.sap_autostart.set_active(True)
+      else:
+        self.sap_autostart.set_active(False)
+    except KeyError, e:
+      self.sap_autostart.set_active(False)
+
     try:
       self.sap_profdir.set_text(attrs["DIR_PROFILE"])
     except KeyError, e:
@@ -552,6 +617,31 @@ class ResourceHandler:
     except KeyError, e:
       self.sap_profname.set_text("")
 
+    try:
+      self.sap_startupwait.set_text(attrs["START_WAITTIME"])
+    except KeyError, e:
+      self.sap_startupwait.set_text("")
+
+    try:
+      self.sap_prestart.set_text(attrs["PRE_START_USEREXIT"])
+    except KeyError, e:
+      self.sap_prestart.set_text("")
+
+    try:
+      self.sap_poststart.set_text(attrs["POST_START_USEREXIT"])
+    except KeyError, e:
+      self.sap_poststart.set_text("")
+
+    try:
+      self.sap_prestop.set_text(attrs["PRE_STOP_USEREXIT"])
+    except KeyError, e:
+      self.sap_prestop.set_text("")
+
+    try:
+      self.sap_poststop.set_text(attrs["POST_STOP_USEREXIT"])
+    except KeyError, e:
+      self.sap_poststop.set_text("")
+
   def pop_openldap(self, attrs):
     self.ld_name.set_text(attrs["name"])
 
@@ -579,6 +669,7 @@ class ResourceHandler:
 
     self.ip.clear()
     self.monitor_link.set_active(True)
+    self.subnet.set_text("")
 
     self.script_name.set_text("")
     self.script_filepath.set_text("")
@@ -669,13 +760,27 @@ class ResourceHandler:
     self.sapdb_tns.set_text("")
     self.sapdb_oraradio.set_active(True)
     self.sapdb_abap_cbox.set_active(False)
+    self.sapdb_appmonitor.set_active(False)
+    self.sapdb_autostart.set_active(False)
     self.sapdb_bootstrap.set_text("")
     self.sapdb_store.set_text("")
+    self.sapdb_sdkpath.set_text("")
+    self.sapdb_jdbc.set_text("")
+    self.sapdb_prestart.set_text("")
+    self.sapdb_poststart.set_text("")
+    self.sapdb_prestop.set_text("")
+    self.sapdb_poststop.set_text("")
 
     self.sap_name.set_text("")
     self.sap_execdir.set_text("")
     self.sap_profname.set_text("")
     self.sap_profdir.set_text("")
+    self.sap_autostart.set_active(False)
+    self.sap_startupwait.set_text("")
+    self.sap_prestart.set_text("")
+    self.sap_poststart.set_text("")
+    self.sap_prestop.set_text("")
+    self.sap_poststop.set_text("")
 
 
   #### Validation Methods
@@ -709,6 +814,9 @@ class ResourceHandler:
           raise ValidationError('FATAL',PROVIDE_UNIQUE_IP)
 
     monitor = self.monitor_link.get_active()
+    subnet = self.subnet.get_text()
+    if subnet != "":
+      addr = addr + "/" + subnet
     fields = {}
     fields["address"]= addr
     if monitor:
@@ -1103,6 +1211,8 @@ class ResourceHandler:
     fields = {}
     fields["name"] = pg_name
     cfg = self.pg_cfg.get_text()
+    if cfg != "" and cfg.find("/") == 0:
+       retval = MessageLibrary.simpleInfoMessage("Config File param does not look like a file path - I hope this is OK")
     fields["config_file"] = cfg
     pmuser = self.pg_pmuser.get_text()
     fields["postmaster_user"] = pmuser
@@ -1226,12 +1336,40 @@ class ResourceHandler:
     fields["DIR_BOOTSTRAP"] = bstrap
     store = self.sapdb_store.get_text()
     fields["DIR_SECSTORE"] = store
+
+    prestart = self.sapdb_prestart.get_text()
+    fields["PRE_START_USEREXIT"] = prestart
+    poststart = self.sapdb_poststart.get_text()
+    fields["POST_START_USEREXIT"] = poststart
+
+    prestop = self.sapdb_prestop.get_text()
+    fields["PRE_STOP_USEREXIT"] = prestop
+    poststop = self.sapdb_poststop.get_text()
+    fields["POST_STOP_USEREXIT"] = poststop
+
+    sdkpath = self.sapdb_sdkpath.get_text()
+    fields["JAVA_HOME"] = sdkpath
+    jdbc = self.sapdb_jdbc.get_text()
+    fields["DB_JARS"] = jdbc
+
     jval = self.sapdb_abap_cbox.get_active()
     if jval == True:
       fields["DBJ2EE_ONLY"] = "TRUE"
     else:
       fields["DBJ2EE_ONLY"] = "FALSE"
 
+    as = self.sapdb_autostart.get_active()
+    if as == True:
+      fields["AUTOMATIC_RECOVER"] = "TRUE"
+    else:
+      fields["AUTOMATIC_RECOVER"] = "FALSE"
+
+    am = self.sapdb_appmonitor.get_active()
+    if am == True:
+      fields["STRICT_MONITORING"] = "TRUE"
+    else:
+      fields["STRICT_MONITORING"] = "FALSE"
+
     dbtype = None
     if self.sapdb_adaradio.get_active() == True:
       dbtype = "ADA"
@@ -1269,6 +1407,25 @@ class ResourceHandler:
     profname = self.sap_profname.get_text()
     fields["START_PROFILE"] = profname
 
+    as = self.sap_autostart.get_active()
+    if as == True:
+      fields["AUTOMATIC_RECOVER"] = "TRUE"
+    else:
+      fields["AUTOMATIC_RECOVER"] = "FALSE"
+
+    prestart = self.sap_prestart.get_text()
+    fields["PRE_START_USEREXIT"] = prestart
+    poststart = self.sap_poststart.get_text()
+    fields["POST_START_USEREXIT"] = poststart
+
+    prestop = self.sap_prestop.get_text()
+    fields["PRE_STOP_USEREXIT"] = prestop
+    poststop = self.sap_poststop.get_text()
+    fields["POST_STOP_USEREXIT"] = poststop
+
+    startupwait = self.sap_startupwait.get_text()
+    fields["START_WAITTIME"] = startupwait
+
     return fields
 
   def val_fs(self, *argname):
@@ -1360,6 +1517,7 @@ class ResourceHandler:
     self.ip.show_all()
     self.rc_xml.get_widget('ip_proxy').add(self.ip)
     self.monitor_link = self.rc_xml.get_widget('checkbutton1')
+    self.subnet = self.rc_xml.get_widget('entry240')
 
     self.script_name = self.rc_xml.get_widget('entry5')
     self.script_filepath = self.rc_xml.get_widget('entry6')
@@ -1420,9 +1578,9 @@ class ResourceHandler:
     self.ap_hopt = self.rc_xml.get_widget('entry30')
     self.ap_wait = self.rc_xml.get_widget('entry31')
 
-    self.lv_name = self.rc_xml.get_widget('entry32')
+    self.lv_name = self.rc_xml.get_widget('entry34')
     self.lv_vgname = self.rc_xml.get_widget('entry33')
-    self.lv_lvname = self.rc_xml.get_widget('entry34')
+    self.lv_lvname = self.rc_xml.get_widget('entry32')
 
     self.mq_name = self.rc_xml.get_widget('entry36')
     self.mq_cfg = self.rc_xml.get_widget('entry37')
@@ -1436,17 +1594,17 @@ class ResourceHandler:
     self.ld_sdopt = self.rc_xml.get_widget('entry43')
     self.ld_wait = self.rc_xml.get_widget('entry44')
 
-    self.pg_name = self.rc_xml.get_widget('entry45')
-    self.pg_cfg = self.rc_xml.get_widget('entry46')
+    self.pg_name = self.rc_xml.get_widget('entry49')
+    self.pg_cfg = self.rc_xml.get_widget('entry48')
     self.pg_pmuser = self.rc_xml.get_widget('entry47')
-    self.pg_pmopt = self.rc_xml.get_widget('entry48')
-    self.pg_wait = self.rc_xml.get_widget('entry49')
+    self.pg_pmopt = self.rc_xml.get_widget('entry46')
+    self.pg_wait = self.rc_xml.get_widget('entry45')
 
-    self.tc_name = self.rc_xml.get_widget('entry51')
-    self.tc_cfg = self.rc_xml.get_widget('entry52')
-    self.tc_tcuser = self.rc_xml.get_widget('entry53')
-    self.tc_copt = self.rc_xml.get_widget('entry55')
-    self.tc_cbase = self.rc_xml.get_widget('entry54')
+    self.tc_name = self.rc_xml.get_widget('entry52')
+    self.tc_cfg = self.rc_xml.get_widget('entry55')
+    self.tc_tcuser = self.rc_xml.get_widget('entry54')
+    self.tc_copt = self.rc_xml.get_widget('entry53')
+    self.tc_cbase = self.rc_xml.get_widget('entry51')
     self.tc_wait = self.rc_xml.get_widget('entry50')
 
     self.sapdb_name = self.rc_xml.get_widget('sapdb_name')
@@ -1458,11 +1616,25 @@ class ResourceHandler:
     self.sapdb_abap_cbox = self.rc_xml.get_widget('abap_cbox')
     self.sapdb_bootstrap = self.rc_xml.get_widget('sapdb_bootstrap')
     self.sapdb_store = self.rc_xml.get_widget('sapdb_store')
+    self.sapdb_appmonitor = self.rc_xml.get_widget('checkbutton3')
+    self.sapdb_autostart = self.rc_xml.get_widget('checkbutton4')
+    self.sapdb_sdkpath = self.rc_xml.get_widget('entry241')
+    self.sapdb_jdbc = self.rc_xml.get_widget('entry242')
+    self.sapdb_prestart = self.rc_xml.get_widget('entry248')
+    self.sapdb_poststart = self.rc_xml.get_widget('entry249')
+    self.sapdb_prestop = self.rc_xml.get_widget('entry250')
+    self.sapdb_poststop = self.rc_xml.get_widget('entry251')
 
     self.sap_name = self.rc_xml.get_widget('sap_name')
     self.sap_execdir = self.rc_xml.get_widget('sap_execdir')
     self.sap_profname = self.rc_xml.get_widget('sap_profname')
     self.sap_profdir = self.rc_xml.get_widget('sap_profdir')
+    self.sap_startupwait= self.rc_xml.get_widget('entry247')
+    self.sap_autostart = self.rc_xml.get_widget('checkbutton5')
+    self.sap_prestart = self.rc_xml.get_widget('entry246')
+    self.sap_poststart = self.rc_xml.get_widget('entry245')
+    self.sap_prestop = self.rc_xml.get_widget('entry244')
+    self.sap_poststop = self.rc_xml.get_widget('entry243')
 
   
   def set_model(self, model_builder):
