@@ -28,6 +28,8 @@ RESOURCE_TYPE=14
 F_NODE_TYPE=15
 F_LEVEL_TYPE=16
 F_FENCE_TYPE=17
+VMS_TYPE=18
+VM_TYPE=19
                                                                                 
 NAME_COL = 0
 TYPE_COL = 1
@@ -45,10 +47,13 @@ RESOURCES_COLOR="#006600"
 RESOURCE_COLOR="#00CC00"
 RESOURCEGROUPS_COLOR="#FF6600"
 RESOURCEGROUP_COLOR="#FF8800"
+VMS_COLOR="#EE22FF"
+VM_COLOR="#FF00FF"
 
 #Attribute Strings
 VOTES_ATTR="votes"
 NAME_ATTR="name"
+NODEID_ATTR="nodeid"
 
 ONE_VOTE=_("1")
 
